==> ovirt-engine-dashboard-1.0.0.tar.gz: ovirt-engine-dashboard-1.0.0/src/utils/intl.js <==
import IntlMessageFormat from 'intl-messageformat'
import getPluginApi from '../plugin-api'
import translatedMessages from '../../intl/translations.json'

// IntlMessageFormat object cache
const messageFormats = {}

// initialized lazily due to UI plugin lifecycle
let locale

// TODO(vs) fetch translations for given locale asynchronously

export function initLocale () {
  locale = getPluginApi().currentLocale()
  !locale && __DEV__ && console.error('Failed to resolve current locale')
}

export function currentLocale () {
  return locale
}

export function translateMessage (id, defaultMessage) {
  const translation = translatedMessages[locale] && translatedMessages[locale][id]

  if (!translation) {
    __DEV__ && console.warn(`Missing [${locale}] translation for message [${id}]`)
    return defaultMessage
  }

  return translation
}

export function formatMessage (id, defaultMessage, values = {}) {
  let fmt = messageFormats[id]

  if (!fmt) {
    fmt = new IntlMessageFormat(translateMessage(id, defaultMessage), locale)
    messageFormats[id] = fmt
  }

  return fmt.format(values)
}

// TODO(vs) use Intl.NumberFormat and Intl.DateTimeFormat (ECMA-402 standard)

export function formatNumber (num, digits) {
  return Number(num.toFixed(digits))
}

export function formatNumber0D (num) {
  return formatNumber(num, 0)
}

export function formatNumber1D (num) {
  return formatNumber(num, 1)
}

export function formatDate (date) {
  return date.toLocaleDateString()
}

export function formatDateTime (date) {
  return `${formatDate(date)} ${date.toLocaleTimeString()}`
}

==> ovirt-engine-dashboard-1.0.3.tar.gz: ovirt-engine-dashboard-1.0.3/src/utils/intl.js <==
import IntlMessageFormat from 'intl-messageformat'
import { defaultLocale } from '../constants'
import translatedMessages from '../../intl/translations.json'

// TODO(vs) this is beyond simple utility functions, extract the code into services/intl

// IntlMessageFormat object cache
const messageFormats = {}

let locale

export function initLocale (currentLocale) {
  locale = currentLocale
}

export function currentLocale () {
  return locale
}

export function translateMessage (id, defaultMessage) {
  const translation = translatedMessages[locale] && translatedMessages[locale][id]

  if (!translation) {
    __DEV__ && console.warn(`Missing [${locale}] translation for message key [${id}]`)
    return defaultMessage
  }

  return translation
}

export function formatMessage (id, defaultMessage, values = {}) {
  let fmt = messageFormats[id]

  if (!fmt) {
    // translation needed only for non-default locale
    const message = (locale !== defaultLocale) ? translateMessage(id, defaultMessage) : defaultMessage

    fmt = new IntlMessageFormat(message, locale)
    messageFormats[id] = fmt
  }

  return fmt.format(values)
}

// TODO(vs) use Intl.NumberFormat and Intl.DateTimeFormat

export function formatNumber (num, digits) {
  return Number(num.toFixed(digits))
}

export function formatNumber0D (num) {
  return formatNumber(num, 0)
}

export function formatNumber1D (num) {
  return formatNumber(num, 1)
}

export function formatDate (date) {
  return date.toLocaleDateString()
}

export function formatDateTime (date) {
  return `${formatDate(date)} ${date.toLocaleTimeString()}`
}
